<!DOCTYPE TS><TS>
<context>
    <name>GameTree</name>
    <message>
        <source>All Games</source>
        <translation>Alla spel</translation>
    </message>
</context>
<context>
    <name>NesSettingsDlg</name>
    <message>
        <source>NES Game Settings - </source>
        <translation>Spelinställningar för NES - </translation>
    </message>
    <message>
        <source> - </source>
        <translation>- </translation>
    </message>
</context>
<context>
    <name>PCSettingsDlg</name>
    <message>
        <source>PC Game Settings - </source>
        <translation>PC-spelinställningar - </translation>
    </message>
    <message>
        <source> - </source>
        <translation>- </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Game display order</source>
        <translation>Visningsordning för spel</translation>
    </message>
    <message>
        <source>MAME binary location</source>
        <translation>Sökväg till MAME</translation>
    </message>
    <message>
        <source>Location of the XMAME emulator binary.</source>
        <translation>Sökväg till XMAME emuleringsprogram.</translation>
    </message>
    <message>
        <source>MAME ROM location</source>
        <translation>Sökväg till MAME-spel</translation>
    </message>
    <message>
        <source>Location of the MAME games.</source>
        <translation>Sökväg till MAME-spel (ROM).</translation>
    </message>
    <message>
        <source>catver.ini file</source>
        <translation>catver.ini-filen</translation>
    </message>
    <message>
        <source>Path to the catver.ini file</source>
        <translation>Sökväg till filen catver.ini</translation>
    </message>
    <message>
        <source>Mame screenshots path</source>
        <translation>Sökväg till skärmdumpar för Mame</translation>
    </message>
    <message>
        <source>Directory where MAME screenshots are kept.</source>
        <translation>Det bibliotek där skärmdumpar för MAME lagras.</translation>
    </message>
    <message>
        <source>MAME hiscores path</source>
        <translation>Sökväg till toppnoteringar för MAME</translation>
    </message>
    <message>
        <source>MAME flyers path</source>
        <translation>Sökväg till MAME-reklamblad</translation>
    </message>
    <message>
        <source>Directory where MAME flyers are kept.</source>
        <translation>Sökväg till biblioteket där reklamblad för MAME lagras.</translation>
    </message>
    <message>
        <source>MAME cabinets path</source>
        <translation>Sökväg till MAME &quot;cabinets&quot;</translation>
    </message>
    <message>
        <source>Directory where MAME cabinets are kept.</source>
        <translation>Sökväg till biblioteket där MAME &quot;cabinets&quot; lagras.</translation>
    </message>
    <message>
        <source>MAME history path</source>
        <translation>Sökväg till MAME-historik</translation>
    </message>
    <message>
        <source>MAME cheat files path</source>
        <translation>Sökväg till fuskfiler för MAME</translation>
    </message>
    <message>
        <source>Show disclaimer</source>
        <translation>Visa avståendeförklaring</translation>
    </message>
    <message>
        <source>Set to show the disclaimer or not</source>
        <translation>Visa/visa inte meddelande om avstående från anspråk (disclaimer)</translation>
    </message>
    <message>
        <source>Show game info</source>
        <translation>Visa spelinformation</translation>
    </message>
    <message>
        <source>Set to show the game info or not</source>
        <translation>Visa/visa inte information om spel</translation>
    </message>
    <message>
        <source>NES binary location</source>
        <translation>Sökväg till NES</translation>
    </message>
    <message>
        <source>Location of the NES emulator binary.</source>
        <translation>Sökväg till NES emuleringsprogram.</translation>
    </message>
    <message>
        <source>NES ROM location</source>
        <translation>Sökväg till NES-spel</translation>
    </message>
    <message>
        <source>Location of the NES games.</source>
        <translation>Sökväg till NES-spel (ROM).</translation>
    </message>
    <message>
        <source>NES CRC file</source>
        <translation>NES CRC-fil</translation>
    </message>
    <message>
        <source>This is the same file that comes with the xmame(xmess) distribution: xmame-0.XX/CRC/nes.crc</source>
        <translation>Detta är samma fil som kommer med xmame(xmess) distribution: xmame-0.XX/CRC/nes.crc</translation>
    </message>
    <message>
        <source>NES screenshots path</source>
        <translation>Sökväg till skärmdumpar för NES</translation>
    </message>
    <message>
        <source>Directory where NES screenshots are kept.</source>
        <translation>Det bibliotek där skärmdumpar för NES lagras.</translation>
    </message>
    <message>
        <source>SNES binary location</source>
        <translation>Sökväg till SNES</translation>
    </message>
    <message>
        <source>Location of the snes9x emulator binary.</source>
        <translation>Sökväg till snes9x emuleringsprogram.</translation>
    </message>
    <message>
        <source>SNES ROM location</source>
        <translation>Sökväg till SNES-spel</translation>
    </message>
    <message>
        <source>Location of the SNES games.</source>
        <translation>Sökväg till SNES-spel (ROM).</translation>
    </message>
    <message>
        <source>SNES screenshots path</source>
        <translation>Sökväg till skärmdumpar för SNES</translation>
    </message>
    <message>
        <source>Directory where SNES screenshots are kept. Looks for screenshots with file names matching the rom file name.</source>
        <translation>Det bibliotek där skärmdumpar för SNES lagras. Letar efter filer som motsvarar namnet på aktuell ROM-fil.</translation>
    </message>
    <message>
        <source>PC Game List xml file</source>
        <translation>Listfil för PC-spel</translation>
    </message>
    <message>
        <source>Path to the Game List xml file. (see README for details)</source>
        <translation>Sökväg till XML-filen som innehåller listan med PC-spel. (Se README-filen för mer detaljer)</translation>
    </message>
    <message>
        <source>PC screenshots path</source>
        <translation>Sökväg till skärmdumpar för PC-spel</translation>
    </message>
    <message>
        <source>Directory where screenshots are kept. Looks for screenshots with file names matching the game name in the Game List xml file.</source>
        <translation>Det bibliotek där skärmdumpar för PC-spel lagras. Letar efter filer som motsvarar namnet på spelet enligt XML-filen som innehåller spellistan.</translation>
    </message>
    <message>
        <source>MythGame Settings -- General</source>
        <translation>Inställningar för MythGame -- Generellt</translation>
    </message>
    <message>
        <source>MythGame Settings -- xmame (page 1)</source>
        <translation>Inställningar för MythGame -- xmame (sida 1)</translation>
    </message>
    <message>
        <source>MythGame Settings -- xmame (page 2)</source>
        <translation>Inställningar för MythGame -- xmame (sida 2)</translation>
    </message>
    <message>
        <source>MythGame Settings -- NES Emulation</source>
        <translation>Inställningar för MythGame -- NES-emulering</translation>
    </message>
    <message>
        <source>MythGame Settings -- SNES Emulation</source>
        <translation>Inställningar för MythGame -- SNES-emulering</translation>
    </message>
    <message>
        <source>MythGame Settings -- PC games</source>
        <translation>Inställningar för MythGame -- PC-spel</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>Loading game...</source>
        <translation>Laddar spel...</translation>
    </message>
    <message>
        <source>Use defaults</source>
        <translation>Använd standardinställningar</translation>
    </message>
    <message>
        <source>Use the global default MAME settings. All other settings are ignored if this is set.</source>
        <translation>Använd globala standardinställningar för MAME. Alla andra inställningar ignoreras om du aktiverar denna option.</translation>
    </message>
    <message>
        <source>Fullscreen mode</source>
        <translation>Helskärmsläge</translation>
    </message>
    <message>
        <source>Windowed</source>
        <translation>Fönsterbaserad</translation>
    </message>
    <message>
        <source>Fullscreen/DGA</source>
        <translation>Helskärm/DGA</translation>
    </message>
    <message>
        <source>Fullscreen/Xv</source>
        <translation>Helskärm/Xv</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Helskärm</translation>
    </message>
    <message>
        <source>Auto frame skip</source>
        <translation>Automatisk bildruteöverhoppning</translation>
    </message>
    <message>
        <source>No Help text</source>
        <translation>Ingen hjälptext</translation>
    </message>
    <message>
        <source>Rotate left</source>
        <translation>Rotera åt vänster</translation>
    </message>
    <message>
        <source>Rotate right</source>
        <translation>Rotera år höger</translation>
    </message>
    <message>
        <source>Flip X Axis</source>
        <translation>Vänd runt X-axeln</translation>
    </message>
    <message>
        <source>Flip Y Axis</source>
        <translation>Vänd runt Y-axeln</translation>
    </message>
    <message>
        <source>Extra Artwork</source>
        <translation>Extra grafik</translation>
    </message>
    <message>
        <source>Scanlines</source>
        <translation>Avsökningslinjer</translation>
    </message>
    <message>
        <source>Automatic color depth</source>
        <translation>Automatiskt färgdjup</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Skalning</translation>
    </message>
    <message>
        <source>Antialiasing</source>
        <translation>Antivikning</translation>
    </message>
    <message>
        <source>Translucency</source>
        <translation>Genomskinlighet</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Upplösning</translation>
    </message>
    <message>
        <source>Use Scale</source>
        <translation>Använd skalning</translation>
    </message>
    <message>
        <source>640 x 480</source>
        <translation>640 x 480</translation>
    </message>
    <message>
        <source>800 x 600</source>
        <translation>800 x 600</translation>
    </message>
    <message>
        <source>1024 x 768</source>
        <translation>1024 x 768</translation>
    </message>
    <message>
        <source>1280 x 1024</source>
        <translation>1280 x 1024</translation>
    </message>
    <message>
        <source>1600 x 1200</source>
        <translation>1600 x 1200</translation>
    </message>
    <message>
        <source>Use sound</source>
        <translation>Använd ljud</translation>
    </message>
    <message>
        <source>Use samples</source>
        <translation>Använd samplar</translation>
    </message>
    <message>
        <source>Fake sound</source>
        <translation>Låtsasljud</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Volym</translation>
    </message>
    <message>
        <source>Enable cheats</source>
        <translation>Använd fusk</translation>
    </message>
    <message>
        <source>Extra options</source>
        <translation>Extra inställningar</translation>
    </message>
    <message>
        <source>Use Windows Keys</source>
        <translation>Använd windowstangenter</translation>
    </message>
    <message>
        <source>Use Mouse</source>
        <translation>Använd mus</translation>
    </message>
    <message>
        <source>Grab Mouse</source>
        <translation>Fånga muspekaren</translation>
    </message>
    <message>
        <source>Joystick Type</source>
        <translation>Typ av styrpinne</translation>
    </message>
    <message>
        <source>No Joystick</source>
        <translation>Ingen styrpinne</translation>
    </message>
    <message>
        <source>i386 Joystick</source>
        <translation>i386-styrpinne</translation>
    </message>
    <message>
        <source>Fm Town Pad</source>
        <translation>Fm Town Pad</translation>
    </message>
    <message>
        <source>X11 Input Extension Joystick</source>
        <translation>Styrpinne för X11 &quot;Input Extension&quot;</translation>
    </message>
    <message>
        <source>New i386 linux 1.x.x Joystick</source>
        <translation>Ny i386 linux 1.x.x styrpinne</translation>
    </message>
    <message>
        <source>NetBSD USB Joystick</source>
        <translation>NetBSD USB-styrpinne</translation>
    </message>
    <message>
        <source>PS2-Linux native pad</source>
        <translation>PS2-Linux originalpad</translation>
    </message>
    <message>
        <source>SDL Joystick</source>
        <translation>SDL-styrpinne</translation>
    </message>
    <message>
        <source>Use joystick as analog</source>
        <translation>Använd styrpinne som analog</translation>
    </message>
    <message>
        <source>Mame Game Settings - </source>
        <translation>Spelinställningar för Mame - </translation>
    </message>
    <message>
        <source> - </source>
        <translation>- </translation>
    </message>
    <message>
        <source> - top level</source>
        <translation>- toppnivå</translation>
    </message>
    <message>
        <source>video page 1</source>
        <translation>video sida 1</translation>
    </message>
    <message>
        <source>video page 2</source>
        <translation>video sida 2</translation>
    </message>
    <message>
        <source>vector</source>
        <translation>vektor</translation>
    </message>
    <message>
        <source>sound</source>
        <translation>ljud</translation>
    </message>
    <message>
        <source>input</source>
        <translation>inmatning</translation>
    </message>
    <message>
        <source>misc</source>
        <translation>diverse</translation>
    </message>
    <message>
        <source>Looking for NES games...</source>
        <translation>Letar efter NES-spel...</translation>
    </message>
    <message>
        <source>Looking for SNES games...</source>
        <translation>Letar efter SNES-spel...</translation>
    </message>
    <message>
        <source>   (bad checksum)</source>
        <translation> (felaktig checksumma)</translation>
    </message>
    <message>
        <source>Use the global default SNES settings. All other settings are ignored if this is set.</source>
        <translation>Använd de globala grundinställningarna för SNES. Alla andra inställningar ignoreras om denna är satt.</translation>
    </message>
    <message>
        <source>Use transparency</source>
        <translation>Använd genomskinlighet</translation>
    </message>
    <message>
        <source>No Help Text</source>
        <translation>Ingen hjälptext</translation>
    </message>
    <message>
        <source>Use 16-bit mode</source>
        <translation>Använd 16-bitarsläge</translation>
    </message>
    <message>
        <source>Use Hi-res mode</source>
        <translation>Använd högupplösningsläge</translation>
    </message>
    <message>
        <source>No modeswitch</source>
        <translation>Inget modbyte</translation>
    </message>
    <message>
        <source>Stretch to fit</source>
        <translation>Sträck för att passa</translation>
    </message>
    <message>
        <source>Interpolation</source>
        <translation>Interpolation</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Interpolate 1</source>
        <translation>Interpolera 1</translation>
    </message>
    <message>
        <source>Interpolate 2</source>
        <translation>Interpolera 2</translation>
    </message>
    <message>
        <source>Interpolate 3</source>
        <translation>Interpolera 3</translation>
    </message>
    <message>
        <source>Interpolate 4</source>
        <translation>Interpolera 4</translation>
    </message>
    <message>
        <source>Interpolate 5</source>
        <translation>Interpolera 5</translation>
    </message>
    <message>
        <source>Layering</source>
        <translation>Skiktning</translation>
    </message>
    <message>
        <source>Interleaved</source>
        <translation>Omlott</translation>
    </message>
    <message>
        <source>AltInterleaved</source>
        <translation>Alt omlott</translation>
    </message>
    <message>
        <source>Hi Rom</source>
        <translation>Högt ROM</translation>
    </message>
    <message>
        <source>Low Rom</source>
        <translation>Lågt ROM</translation>
    </message>
    <message>
        <source>Header</source>
        <translation>Huvud</translation>
    </message>
    <message>
        <source>No Header</source>
        <translation>Inget huvud</translation>
    </message>
    <message>
        <source>NTSC</source>
        <translation>NTSC</translation>
    </message>
    <message>
        <source>PAL</source>
        <translation>PAL</translation>
    </message>
    <message>
        <source>No HDMA</source>
        <translation>Ingen HDMA</translation>
    </message>
    <message>
        <source>No Windows</source>
        <translation>Inga fönster</translation>
    </message>
    <message>
        <source>No Speed Hacks</source>
        <translation>Inga hastighetsmodifieringar</translation>
    </message>
    <message>
        <source>No Sound</source>
        <translation>Inget ljud</translation>
    </message>
    <message>
        <source>Use stereo audio</source>
        <translation>Använd stereoljud</translation>
    </message>
    <message>
        <source>Envx</source>
        <translation>Envx</translation>
    </message>
    <message>
        <source>No Echo</source>
        <translation>Inget eko</translation>
    </message>
    <message>
        <source>Threaded Sound</source>
        <translation>Trådat ljud</translation>
    </message>
    <message>
        <source>Synced Sound</source>
        <translation>Synkroniserat ljud</translation>
    </message>
    <message>
        <source>Interpolated Sound</source>
        <translation>Interpolerat ljud</translation>
    </message>
    <message>
        <source>No sample caching</source>
        <translation>Ingen &quot;caching&quot; av samplar</translation>
    </message>
    <message>
        <source>Alt sample decoding</source>
        <translation>Alt avkodning av samplar</translation>
    </message>
    <message>
        <source>No master volume</source>
        <translation>Ingen huvudvolym</translation>
    </message>
    <message>
        <source>Audio buffer size</source>
        <translation>Ljudbuffertstorlek</translation>
    </message>
    <message>
        <source>Sound skip</source>
        <translation>Ljudhopp</translation>
    </message>
    <message>
        <source>Sound quality</source>
        <translation>Ljudkvalitet</translation>
    </message>
    <message>
        <source>SNES Game Settings - </source>
        <translation>Spelinställningar för SNES - </translation>
    </message>
    <message>
        <source>video</source>
        <translation>video</translation>
    </message>
    <message>
        <source>misc page 1</source>
        <translation>diverse sida 1</translation>
    </message>
    <message>
        <source>misc page 2</source>
        <translation>diverse sida 2</translation>
    </message>
    <message>
        <source>sound page 1</source>
        <translation>ljud sida 1</translation>
    </message>
    <message>
        <source>sound page 2</source>
        <translation>ljud sida 2</translation>
    </message>
    <message>
        <source>Show Only Favorites</source>
        <translation>Visa endast favoriter</translation>
    </message>
    <message>
        <source>Limit games listed to only those tagged as &quot;favorite&quot;</source>
        <translation>Begränsa listade spel till de märkta som &quot;favoriter&quot;</translation>
    </message>
    <message>
        <source>The path to the MAME history.dat file.</source>
        <translation>Sökvägen till MAME-filen history.dat.</translation>
    </message>
    <message>
        <source>The path to the MAME cheat.dat file.</source>
        <translation>Sökvägen till MAME-filen cheat.dat.</translation>
    </message>
    <message>
        <source>Wrong xmame version.</source>
        <translation>Fel xmame-version.</translation>
    </message>
    <message>
        <source>This version of xmame is not supported.</source>
        <translation>Denna version av xmame stöds ej.</translation>
    </message>
    <message>
        <source>Failed to read catver.ini</source>
        <translation>Kan inte läsa catver.ini</translation>
    </message>
    <message>
        <source>MythTV was unable to read catver.ini.
Please enter the correct path and try again.</source>
        <translation>MythTV kunde inte läsa catver.ini
Ange korrekt sökväg och försök igen.</translation>
    </message>
    <message>
        <source>Order in which to sort the games - this is for all systems. Available choices: system, year, genre and gamename</source>
        <translation>Sorteringsordning för spelen - detta gäller alla system. Tillgängliga val: system, år, genre och spelnamn</translation>
    </message>
    <message>
        <source>MAME image downloader</source>
        <translation>MAME bildnedladdare</translation>
    </message>
    <message>
        <source>The path to the MAME image downloader helper.  (See the contrib/ dir in the mythgame source.)</source>
        <translation>Sökväg till MAME bildnedladdare. (Se katalogen contrib/ i mythgame-källkoden.)</translation>
    </message>
    <message>
        <source>Automatically download images</source>
        <translation>Ladda ner bilder automatiskt</translation>
    </message>
    <message>
        <source>Attempt to automatically download ROM images if they don&apos;t exist.</source>
        <translation>Försök ladda ner ROM-bilder automatiskt om de inte finns.</translation>
    </message>
    <message>
        <source>SNES Emulator</source>
        <translation>SNES-emulator</translation>
    </message>
    <message>
        <source>SNES9x</source>
        <translation>SNES9x</translation>
    </message>
    <message>
        <source>zSNES</source>
        <translation>zSNES</translation>
    </message>
    <message>
        <source>Which emulator to use</source>
        <translation>Emulator att använda</translation>
    </message>
    <message>
        <source>Enable autoframeskip</source>
        <translation>Hoppa över bildrutor</translation>
    </message>
    <message>
        <source>Rotate screen anti-clockwise</source>
        <translation>Rotera skärm motsols</translation>
    </message>
    <message>
        <source>Rotate screen clockwise</source>
        <translation>Rotera skärm medsols</translation>
    </message>
    <message>
        <source>Flip screen left-right</source>
        <translation>Vänd skärm vänster-höger</translation>
    </message>
    <message>
        <source>Flip screen upside-down</source>
        <translation>Vänd skärm uppochner</translation>
    </message>
    <message>
        <source>Use additional game artwork</source>
        <translation>Använd extra spel-artwork</translation>
    </message>
    <message>
        <source>Enable displaying simulated scanlines</source>
        <translation>Visa simulerade scanningslinjer</translation>
    </message>
    <message>
        <source>Enable antialiasing</source>
        <translation>Aktivera antialiasing</translation>
    </message>
    <message>
        <source>Beam</source>
        <translation>Stråle</translation>
    </message>
    <message>
        <source>Set the beam size for vector games (float)</source>
        <translation>Sätt strålstorlek för vektorspel (flyttal)</translation>
    </message>
    <message>
        <source>Flicker</source>
        <translation>Flimmer</translation>
    </message>
    <message>
        <source>Set the flicker for vector games (float)</source>
        <translation>Sätt flimmer för vektorspel (flyttal)</translation>
    </message>
    <message>
        <source>Enable sound (if available)</source>
        <translation>Aktivera ljud (om tillgängligt)</translation>
    </message>
    <message>
        <source>Enable samples (if available)</source>
        <translation>Aktivera samplingar (om tillgängligt)</translation>
    </message>
    <message>
        <source>Enable cheat subsystem</source>
        <translation>Aktivera fusk-undersystem</translation>
    </message>
    <message>
        <source>Enable mouse (if supported)</source>
        <translation>Aktivera mus (om stöd finns)</translation>
    </message>
    <message>
        <source>Select type of joystick support to use</source>
        <translation>Välj typ av joystick-stöd</translation>
    </message>
    <message>
        <source>Use Joystick as analog for analog controls</source>
        <translation>Använd joystick som analog för analoga kontroller</translation>
    </message>
    <message>
        <source>Directory where MAME hiscores are kept.</source>
        <translation>Katalog där MAME bästa resultat lagras.</translation>
    </message>
    <message>
        <source>MAME hiscores file</source>
        <translation>MAME-fil för bästa resultat</translation>
    </message>
    <message>
        <source>Path to the MAME hiscore.dat file</source>
        <translation>Sökväg till MAME-filen hiscore.dat</translation>
    </message>
    <message>
        <source>Atari binary location</source>
        <translation>Plats för Atari-binär</translation>
    </message>
    <message>
        <source>Location of the Atari emulator binary.</source>
        <translation>Plats för Atari emulatorbinärfilen.</translation>
    </message>
    <message>
        <source>Atari ROM location</source>
        <translation>Plats för Atari ROM</translation>
    </message>
    <message>
        <source>Location of the Atari games.</source>
        <translation>Plats för Atari-spelen.</translation>
    </message>
    <message>
        <source>Odyssey2 binary location</source>
        <translation>Plats för Odyssey2-binär</translation>
    </message>
    <message>
        <source>Location of the Odyssey2 emulator binary.</source>
        <translation>Plats för Odyssey2 emulatorbinärfilen.</translation>
    </message>
    <message>
        <source>Odyssey2 ROM location</source>
        <translation>Plats för Odyssey2 ROM</translation>
    </message>
    <message>
        <source>Location of the Odyssey2 games.</source>
        <translation>Plats för Odyssey2-spelen.</translation>
    </message>
    <message>
        <source>MythGame Settings -- Atari Emulation</source>
        <translation>MythGameinställningar -- Atari-emulering</translation>
    </message>
    <message>
        <source>MythGame Settings -- Odyssey2 Emulation</source>
        <translation>MythGameinställningar -- Odyssey2-emulering</translation>
    </message>
    <message>
        <source>Set X-Y Scale to the same aspect ratio. For vector games scale may have values like 1.5 and even 0.5. For scaling of regular games this will be rounded to an int</source>
        <translation>Sätt X-Y-skala till samma bildaspekt. För vektorspel kan skalan ha värden som 1.5 eller t.o.m. 0.5. För skalning av vanliga spel avrundas detta till ett heltal</translation>
    </message>
    <message>
        <source>Enable translucency</source>
        <translation>Aktivera genomskinlighet</translation>
    </message>
    <message>
        <source>Always scale vectorgames to X x Y, keeping their aspect ratio. This overrides the scale options.</source>
        <translation>Skala alltid vektorspel till X x Y och bevara bildaspekt. Detta åsidosätter skalningsinställningarna.</translation>
    </message>
    <message>
        <source>Generate sound even when sound is disabled. This is needed for some games which won&apos;t run without sound.</source>
        <translation>Skapa ljud även när ljud är avstängt. Detta behövs för några spel som inte vill starta utan ljud.</translation>
    </message>
    <message>
        <source>Set volume to x db, (-32 (soft) - 0 (loud) )</source>
        <translation>Sätt volym till x dB, (-32 (låg) - 0 (hög) )</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>System:</source>
        <translation>System:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>År:</translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <source>Favorite:</source>
        <translation>Favorit:</translation>
    </message>
</context>
</TS>
